<template>
  <el-config-provider :size="getGlobalComponentSize" :locale="getGlobalI18n">
    <!-- <header className="headerTop">
      <div className="logo"> <img :src="logo" style="max-width:186px" /></div>
      <div className="menuTabs">
        <ul>
          <li @click="tabGis">指挥调度</li>
          <li @click="tabBussiness" class="active">业务管理</li>
        </ul>
      </div>
    </header> -->
    <!-- <router-view v-show="themeConfig.lockScreenTime > 1" v-if="isRouterAlive" /> -->
    <router-view v-if="isRouterAlive" :key="key" />
    <LockScreen v-if="themeConfig.isLockScreen" />
    <Setings ref="setingsRef" v-show="themeConfig.lockScreenTime > 1" />
    <CloseFull v-if="!themeConfig.isLockScreen" />
    <!-- <Upgrade v-if="getVersion" /> -->
  </el-config-provider>
</template>

<script setup lang="ts" name="app">
import { defineAsyncComponent, computed, ref, onBeforeMount, onMounted, onUnmounted, nextTick, watch, provide } from 'vue';
import { useRoute } from 'vue-router';
import { useI18n } from 'vue-i18n';
import { storeToRefs } from 'pinia';
import { useTagsViewRoutes } from '/@/stores/tagsViewRoutes';
import { useThemeConfig } from '/@/stores/themeConfig';
import other from '/@/utils/other';
import { Local, Session } from '/@/utils/storage';
import mittBus from '/@/utils/mitt';
import setIntroduction from '/@/utils/setIconfont';
import logo from '/@/assets/警保联动指挥调度平台@2x.png'
// 引入组件
const LockScreen = defineAsyncComponent(() => import('/@/layout/lockScreen/index.vue'));
const Setings = defineAsyncComponent(() => import('/@/layout/navBars/breadcrumb/setings.vue'));
const CloseFull = defineAsyncComponent(() => import('/@/layout/navBars/breadcrumb/closeFull.vue'));
const Upgrade = defineAsyncComponent(() => import('/@/layout/upgrade/index.vue'));

// 定义变量内容
const { messages, locale } = useI18n();
const setingsRef = ref();
const route = useRoute();
const stores = useTagsViewRoutes();
const storesThemeConfig = useThemeConfig();
const { themeConfig } = storeToRefs(storesThemeConfig);
const isRouterAlive = ref(true)//刷新路由判断
//获取router-view的key,刷新路由
const key = computed(() => {
  console.log('key1', route.fullPath)
  return route.fullPath;//刷新路由
})
// 获取版本号
const getVersion = computed(() => {
  let isVersion = false;
  if (route.path !== '/login') {
    // @ts-ignore  表示忽略错误，跳过类型检查,__VERSION__能获取到vite.config.js配置文件define定义的变量   
    if ((Local.get('version') && Local.get('version') !== __VERSION__) || !Local.get('version')) isVersion = true;
  }
  return isVersion;
});
// 获取全局组件大小
const getGlobalComponentSize = computed(() => {
  return other.globalComponentSize();
});
// 获取全局 i18n
const getGlobalI18n = computed(() => {
  return messages.value[locale.value];
});
//路由刷新
const reload = () => {
  isRouterAlive.value = false
  nextTick(() => {
    isRouterAlive.value = true
  })
}
const tabGis = () => {
  const w: Window | null = window.open('', "_self")
  w!.location.href = "https://v5qy.te.baibaodun.com.cn/static/signon/dispatchReact";
}
const tabBussiness = () => {
  return
}
provide('reload', reload)//App.vue父级传递给子孙刷新
// 设置初始化，防止刷新时恢复默认
onBeforeMount(() => {
  // 设置批量第三方 icon 图标
  setIntroduction.cssCdn();
  // 设置批量第三方 js
  setIntroduction.jsCdn();
});
// 获取iframe嵌套的平台
const getIframePlatform = () => {
	const regexpParam = /\??([\w\d%]+)=([\w\d%]*)&?/g; //分离参数的正则表达式
	const url = window.location.href; //取得iframe的url 
	let ret;       
	const paramMap = {} as any;//初始化结果集
	//开始循环查找url中的参数，并以键值对形式放入结果集
	while((ret = regexpParam.exec(url)) != null) {
		//ret[1]是参数名，ret[2]是参数值
		paramMap[ret[1]] = ret[2];
	}
  console.log("当前业务管理的2url=",url,"获取到的platform信息为",paramMap);
  const urlParams = new URLSearchParams(window.location.search);
  const paramValue = urlParams.get('platform');
  if(paramMap.platform){
    paramMap["platform"] = paramValue;
  }
  Session.set('platform', paramMap.platform || '1')
}
// 页面加载时
onMounted(() => {
  console.log("process", process.env.NODE_ENV)
  nextTick(() => {
    // 监听布局配'置弹窗点击打开
    mittBus.on('openSetingsDrawer', () => {
      setingsRef.value.openDrawer();
    });
    // 获取缓存中的布局配置
    if (Local.get('themeConfig')) {
      storesThemeConfig.setThemeConfig({ themeConfig: Local.get('themeConfig') });
      document.documentElement.style.cssText = Local.get('themeConfigStyle');
    }
    // 获取缓存中的全屏配置
    if (Session.get('isTagsViewCurrenFull')) {
      stores.setCurrenFullscreen(Session.get('isTagsViewCurrenFull'));
    }
    console.log("执行当前的getIframePlatform2222222");
    getIframePlatform(); //获取平台
  });
});
// 页面销毁时，关闭监听布局配置/i18n监听
onUnmounted(() => {
  mittBus.off('openSetingsDrawer', () => { });
});
// 监听路由的变化，设置网站标题
watch(
  () => route.path,
  () => {
    other.useTitle();
  },
  {
    deep: true,
  }
);
</script>
<style lang="scss">
.flexL {
  margin-right: 30px;
}

.flexR {
  position: absolute;
  right: 40px;
  top: 35px;

  .el-icon {
    cursor: pointer;
    font-size: 20px;
  }
}

.headerTop {
  display: flex;
  background: #fff !important;
  height: 54px;
  line-height: 54px;
  padding: 0 10px;

  .logo {
    height: 54px;
    line-height: 54px;
    padding-left: 0px;
    margin-right: 40px;

    img {
      vertical-align: middle;
    }
  }

  .menuTabs {
    ul {
      list-style: none;
      display: flex;

      li {
        margin-right: 34px;
        height: 54px;
        line-height: 54px;
        cursor: pointer;

        &.active {
          color: #0E70FF;
          border-bottom: 2px solid #0E70FF;
        }
      }
    }
  }
}
</style>
